from Event_sensor.event_tools import *

# generate_images_accumu_eds("D:/2024/3DGS/Nerf_Event/data/eds/09_ziggy_flying_pieces/",13513*10,140,1)
# generate_images_accumu_edslike("D:/2024/3DGS/Nerf_Event/data/eds/09_ziggy_flying_pieces/",13513*10,140,1)
# generate_images_eds("D:/2024/3DGS/Nerf_Event/data/eds/09_ziggy_flying_pieces/",13300*10,140)
# generate_images_accumu_T("D:/2024/3DGS/e2calib/trans_1mps_H_R2L",21153,51,1)
# generate_images_accumu_Tumvie("D:/2024/3DGS/Nerf_Event/data/tumvie/mocap-desk2-events_left",52631,424,1)
# generate_images("D:/2024/3DGS/dataset/nerf_synthetic/mic_colmap_easy/Esim_display",1000,104)
# generate_images_accumu("D:/2024/3DGS/dataset/nerf_synthetic/mic_colmap_easy/Esim",1000,104)
# generate_images_accumu_volt("D:/2024/3DGS/dataset/nerf_synthetic/mic_colmap_easy/",1000,104)

# generate_single_image("D:/2024/3DGS/PureEventFilter/data/dynamic_high_colmap_easy/dynamic_high_volt.txt","85.png",42.523*1e6,42.527*1e6)

# generate_single_image("D:/2024/3DGS/dataset/nerf_synthetic/train_colmap_easy/train_volt.txt","5.png",0.0049*1e6,0.0051*1e6)
# generate_single_image("D:/2024/3DGS/dataset/nerf_synthetic/train_colmap_easy/train_volt.txt","15.png",0.0149*1e6,0.0151*1e6)
# generate_single_image("D:/2024/3DGS/dataset/nerf_synthetic/train_colmap_easy/train_volt.txt","25.png",0.0249*1e6,0.0251*1e6)
# generate_single_image("D:/2024/3DGS/dataset/nerf_synthetic/train_colmap_easy/train_volt.txt","35.png",0.0349*1e6,0.0351*1e6)
# generate_single_image("D:/2024/3DGS/dataset/nerf_synthetic/train_colmap_easy/train_volt.txt","45.png",0.0449*1e6,0.0451*1e6)

# generate_single_image("D:/2024/3DGS/PureEventFilter/data/lego_color_colmap_easy/lego_volt.txt","5.png",0.0049*1e6,0.0051*1e6)
# generate_single_image("D:/2024/3DGS/PureEventFilter/data/lego_color_colmap_easy/lego_volt.txt","45.png",0.0449*1e6,0.0451*1e6)
# generate_single_image("D:/2024/3DGS/PureEventFilter/data/lego_color_colmap_easy/lego_volt.txt","85.png",0.0849*1e6,0.0851*1e6)


# generate_3D("D:/2024/3DGS/PureEventFilter/data/lego_colmap_easy/lego_volt.txt",0*1e6,0.001*1e6)
# generate_3D("D:/2024/3DGS/PureEventFilter/data/boxes_6dof_colmap_easy/boxes.txt",1*1e6,1.010*1e6)
generate_single_image("D:/2024/3DGS/PureEventFilter/data/boxes_6dof_colmap_easy/boxes.txt","85.png",5.11*1e6,5.12*1e6)
